Struct rune_modules::http::StatusCode
source · pub struct StatusCode { /* private fields */ }Trait Implementations
sourceimpl Debug for StatusCode
impl Debug for StatusCode
sourceimpl InstallWith for StatusCode
impl InstallWith for StatusCode
sourcefn install_with(module: &mut Module) -> Result<(), ContextError>
fn install_with(module: &mut Module) -> Result<(), ContextError>
Hook to install more things into the module.
sourceimpl Named for StatusCode
impl Named for StatusCode
sourceimpl TypeOf for StatusCode
impl TypeOf for StatusCode
sourceimpl UnsafeFromValue for &StatusCode
impl UnsafeFromValue for &StatusCode
type Output = *const StatusCode
type Output = *const StatusCode
The output type from the unsafe coercion.
sourcefn from_value(value: Value) -> Result<(Self::Output, Self::Guard), VmError>
fn from_value(value: Value) -> Result<(Self::Output, Self::Guard), VmError>
Convert the given reference using unsafe assumptions to a value. Read more
sourceunsafe fn unsafe_coerce(output: Self::Output) -> Self
unsafe fn unsafe_coerce(output: Self::Output) -> Self
Coerce the output of an unsafe from value into the final output type. Read more
sourceimpl UnsafeFromValue for &mut StatusCode
impl UnsafeFromValue for &mut StatusCode
type Output = *mut StatusCode
type Output = *mut StatusCode
The output type from the unsafe coercion.
sourcefn from_value(value: Value) -> Result<(Self::Output, Self::Guard), VmError>
fn from_value(value: Value) -> Result<(Self::Output, Self::Guard), VmError>
Convert the given reference using unsafe assumptions to a value. Read more
sourceunsafe fn unsafe_coerce(output: Self::Output) -> Self
unsafe fn unsafe_coerce(output: Self::Output) -> Self
Coerce the output of an unsafe from value into the final output type. Read more
sourceimpl UnsafeToValue for &StatusCode
impl UnsafeToValue for &StatusCode
sourceimpl UnsafeToValue for &mut StatusCode
impl UnsafeToValue for &mut StatusCode